DependencyAnalysisResult class
Constructors
-
DependencyAnalysisResult({required List<
Dependency> directDependencies, required List<LockedDependency> lockedDependencies, required DependencyGraph graph, required List<PackageHealth> health}) -
const
Properties
- devDependencyCount → int
-
no setter
-
directDependencies
→ List<
Dependency> -
final
- graph → DependencyGraph
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
health
→ List<
PackageHealth> -
final
-
lockedDependencies
→ List<
LockedDependency> -
final
- productionDependencyCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitiveDependencyCount → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited