DependencyGraph class

Constructors

DependencyGraph({required List<LockedDependency> dependencies})

Properties

devPackages List<LockedDependency>
no setter
directPackages List<LockedDependency>
no setter
hashCode int
The hash code for this object.
no setterinherited
packageCount int
no setter
packages Map<String, LockedDependency>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitivePackages List<LockedDependency>
no setter

Methods

contains(String packageName) bool
findDependents(String packageName) List<String>
getDependencies(String packageName) List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited