PackageHealth class

Constructors

PackageHealth({required String packageName, required String currentVersion, required String? latestVersion, required HealthStatus status, required List<String> issues, required List<String> recommendations})
const

Properties

currentVersion String
final
hashCode int
The hash code for this object.
no setterinherited
isOutdated bool
no setter
issues List<String>
final
latestVersion String?
final
packageName String
final
recommendations List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int
no setter
status HealthStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited