LockedDependency class

Constructors

LockedDependency({required String name, required String version, required String source, required String kind, required List<String> dependencies, required List<String> directDependencies, required List<String> devDependencies})
const

Properties

dependencies List<String>
final
devDependencies List<String>
final
directDependencies List<String>
final
hashCode int
The hash code for this object.
no setterinherited
isDev bool
no setter
isDirect bool
no setter
isTransitive bool
no setter
kind String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited